@@ -8,7 +8,7 @@ class Socket:
     PROTO_LOOKUP = {"icmp": socket.IPPROTO_ICMP, "tcp": socket.IPPROTO_TCP, "udp": socket.IPPROTO_UDP,
                     "ip": socket.IPPROTO_IP, "raw": socket.IPPROTO_RAW}
 
-    def __init__(self, destination, protocol, source=None, options=(), buffer_size=2048):
+    def __init__(self, destination, protocol, options=(), buffer_size=2048, source=None):
         """Creates a network socket to exchange messages
 
         :param destination: Destination IP address
@@ -28,9 +28,8 @@ class Socket:
 
         self.protocol = Socket.getprotobyname(protocol)
         self.buffer_size = buffer_size
-        if source is not None:
-            raise NotImplementedError('PythonPing currently does not support specification of source IP')
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_RAW, self.protocol)
+        self.source = source
         if options:
             self.socket.setsockopt(*options)
 
@@ -53,6 +52,8 @@ class Socket:
 
         :param packet: The raw packet to send
         :type packet: bytes"""
+        if self.source:
+            self.socket.bind((self.source, 0))
         self.socket.sendto(packet, (self.destination, 0))
 
     def receive(self, timeout=2):
@@ -80,4 +81,4 @@ class Socket:
                 self.socket.close()
         except AttributeError:
             raise AttributeError("Attribute error because of failed socket init. Make sure you have the root privilege."
-                                 " This error may also be caused from DNS resolution problems.")
\ No newline at end of file
+                                 " This error may also be caused from DNS resolution problems.")
